@@ -2,7 +2,7 @@ package Devel::Declare::Lexer::Token::String;
 
 use base qw/ Devel::Declare::Lexer::Token /;
 
-use Devel::Declare::Lexer::Interpolator;
+use Devel::Declare::Lexer::Token::String::Interpolator;
 
 use v5;
 
@@ -29,13 +29,13 @@ sub deinterpolate
 {
     my ($self) = @_;
 
-    return Devel::Declare::Lexer::Interpolator::deinterpolate($self->{value});
+    return Devel::Declare::Lexer::Token::String::Interpolator::deinterpolate($self->{value});
 }
 
 sub interpolate
 {
     my ($self, @args) = @_;
-    return Devel::Declare::Lexer::Interpolator::interpolate($self->{value}, @args);
+    return Devel::Declare::Lexer::Token::String::Interpolator::interpolate($self->{value}, @args);
 }
 
 1;
